{{ define "head" }}
  <link
    rel="alternate"
    type="application/rss+xml"
    title="{{ translate "general.events" }} | {{ translate "general.feed_rss" }}"
    href="/rss"
  />
  <link
    rel="alternate"
    type="text/calendar"
    title="{{ translate "general.events" }} | {{ translate "general.feed_ical" }}"
    href="/ical"
  />

  <link rel="stylesheet" href="/assets/css/eventlist.css" />
  <script src="/assets/js/eventlist.js"></script>

  <script>
    if ('serviceWorker' in navigator) {
      navigator.serviceWorker.register('/serviceworker.js', { scope: '/' });
    }
  </script>
{{ end }}
{{ define "robots" }}{{ if not .Options.ShouldIndex }}noindex, nofollow{{ end }}{{ end }}

{{ define "beforeHeader" }}{{ end }}

{{ define "beforeBurgerMenu" }}
  <form method="GET" action="/" class="search">
    {{ if .Options.Tags }}
      {{ range .Options.Tags }}
        <input type="hidden" name="tags" value="{{ . }}" />
      {{ end }}
    {{ end }}
    {{ if not .Options.DateIsDefault }}
      <input type="hidden" name="date" value="{{ .Options.Calendar.Format "2006-01-02" }}" />
    {{ end }}
    {{ if not .Options.CalendarIsDefault }}
      <input type="hidden" name="calendar" value="{{ .Options.Calendar.Format "2006-01" }}" />
    {{ end }}
    <input placeholder="Suche" name="query" value="{{ .Options.Query }}" />
    <button aria-label="Suche" type="submit">
      <img src="/assets/images/icon_search.svg" alt="{{ translate "images.icon_search" }}" />
    </button>
  </form>
{{ end }}

{{ define "main" }}
  <div class="main invert-order-mobile">
    <div class="left">
      {{ template "left" . }}
    </div>
    <aside class="right">
      {{ template "right" . }}
    </aside>
  </div>
{{ end }}

{{ define "left" }}
  {{ if not .Days }}
    <section class="container">
      <div class="container-header caps">
        <h2>{{ translate "general.events" }}</h2>
      </div>
      <div class="container-content">
        {{- if .Options.Date.IsZero -}}
          {{- translate "messages.no_events" -}}
        {{- else -}}
          {{- translate "messages.no_events_on_date" -}}
        {{- end -}}
      </div>
    </section>
  {{ end }}
  {{ template "eventlistDays" dict "Days" .Days "Options" $.Options }}
  <div
    class="pagination"
    {{ if .Options.HasNextPage }}
      data-fetch-url="{{ joinPath .BaseURL "partial/eventlist" }}{{ .Options.URL }}"
      data-pages="{{ json .Options.Pages }}"
    {{ end }}
  >
    <div class="pagination-error hidden"></div>
    <div class="pagination-btn-container">
      {{ if .Options.HasPrevPage }}
        <a
          class="prev"
          href="{{ (.Options.PrevPage).URL }}"
          title="{{ translate "navigation.previous_page" }}"
          ><img
            src="/assets/images/icon_arrow_right.svg"
            alt="{{ translate "images.icon_arrow_left" }}"
          />{{ translate "navigation.revious_page" }}</a
        >
      {{ else }}
        <span></span>
      {{ end }}
      {{ if .Options.HasNextPage }}
        <a href="{{ (.Options.NextPage).URL }}" title="{{ translate "navigation.next_page" }}"
          >{{ translate "navigation.next_page" }}<img
            src="/assets/images/icon_arrow_right.svg"
            alt="{{ translate "images.icon_arrow_right" }}"
        /></a>
      {{ else }}
        <span></span>
      {{ end }}
    </div>
  </div>
  <div class="loading-box hidden">
    <div class="lds-ring">
      <div></div>
      <div></div>
      <div></div>
      <div></div>
    </div>
  </div>
{{ end }}

{{ define "right" }}
  {{ $activeFilters := len .Options.Tags }}
  <div class="tabs">
    <nav class="open">
      <a href="#calendar">{{ translate "general.calendar" }}</a>
      <a href="#filter"
        >{{ translate "general.filter" }}
        {{ if gt $activeFilters 0 }}({{ $activeFilters }}){{ end }}</a
      >
      <a href="#feed">{{ translate "general.feed" }}</a>
    </nav>
    <div id="calendar">
      <nav>
        <a href="#" class="active">{{ translate "general.calendar" }}</a>
        <a href="#filter"
          >{{ translate "general.filter" }}
          {{ if gt $activeFilters 0 }}({{ $activeFilters }}){{ end }}</a
        >
        <a href="#feed">{{ translate "general.feed" }}</a>
      </nav>
      {{ template "eventlist-calendar" dict "Options" .Options "Calendar" .Calendar "Today" .Today "BaseURL" .BaseURL }}
    </div>
    <div id="filter">
      <nav>
        <a href="#calendar">{{ translate "general.calendar" }}</a>
        <a href="#" class="active"
          >{{ translate "general.filter" }}
          {{ if gt $activeFilters 0 }}({{ $activeFilters }}){{ end }}</a
        >
        <a href="#feed">{{ translate "general.feed" }}</a>
      </nav>
      {{ template "eventlist-filter" dict "Options" .Options "Tags" .Tags "Categories" .Categories "Topics" .Topics }}
    </div>
    <div id="feed">
      <nav>
        <a href="#calendar">{{ translate "general.calendar" }}</a>
        <a href="#filter"
          >{{ translate "general.filter" }}
          {{ if gt $activeFilters 0 }}({{ $activeFilters }}){{ end }}</a
        >
        <a href="#" class="active">{{ translate "general.feed" }}</a>
      </nav>
      {{ template "eventlist-feed" }}
    </div>
  </div>
{{ end }}

{{ define "eventlist-categories" }}
  <section class="container">
    <div class="container-header caps">
      {{ translate "general.categories" }}
    </div>
    <div class="container-content filter">
      {{ range .Categories }}
        {{ $categoriesList := len .Options.Tags }}
        <a href="{{ translatef "url.category" .ID }}">{{ .Name }}</a>
      {{ end }}
    </div>
  </section>
{{ end }}

{{ define "eventlist-topics" }}
  <section class="container">
    <div class="container-header caps">
      {{ translate "general.categories" }}
    </div>
    <div class="container-content filter">
      {{ range .Topics }}
        <a href="{{ translatef "url.topic" .ID }}">{{ .Name }}</a>
      {{ end }}
    </div>
  </section>
{{ end }}

{{ define "eventlist-filter" }}
  <section class="container" id="{{ .ID }}">
    <div class="container-header caps">
      {{ translate "general.filter" }}
    </div>
    <div class="container-content">
      <h2 class="container-subheader">{{ translate "general.categories" }}</h2>
      <div class="container-subcontent filter" id="categories">
        {{ range .Categories }}
          <a href="{{ translatef "url.category" .ID }}">{{ .Name }}</a>
        {{ end }}
      </div>
      <h2 class="container-subheader">{{ translate "general.topics" }}</h2>
      <div class="container-subcontent filter" id="topics">
        {{ range .Topics }}
          <a href="{{ translatef "url.topic" .ID }}">{{ .Name }}</a>
        {{ end }}
      </div>
      <h2 class="container-subheader tags">Tags</h2>
      <div class="tags-list">
        <a class="tags-link" href="#tags">{{ translate "general.show" }}</a>
        <div class="container-subcontent filter" id="tags">
          {{ range .Tags }}
            {{ $options := $.Options.ToggleTag .Term }}
            <a
              class="{{ if $.Options.HasTag .Term }}active{{ end }}"
              href="{{ $options.URL }}"
              {{ if not $options.ShouldIndex }}rel="noindex, nofollow"{{ end }}
              >#{{ .Term }}</a
            >
          {{ end }}
        </div>
      </div>
      <h2 class="container-subheader regular">{{ translate "general.repeating_events" }}</h2>
      <div class="regular-filter">
        <div class="container-subcontent filter" id="regular-filter-container">
          {{ $optionsNoRepeating := $.Options.ToggleNoRepeatingFilter }}
          <a
            class="{{ if $.Options.HasNoRepeatingFilter }}active{{ end }}"
            href="{{ $optionsNoRepeating.URL }}"
            >{{ translate "general.only_one_time" }}</a
          >
          {{ $optionsOnlyRepeating := $.Options.ToggleOnlyRepeatingFilter }}
          <a
            class="{{ if $.Options.HasOnlyRepeatingFilter }}active{{ end }}"
            href="{{ $optionsOnlyRepeating.URL }}"
            >{{ translate "general.only_repeating" }}</a
          >
        </div>
      </div>
    </div>
  </section>
{{ end }}

{{ define "eventlist-feed" }}
  <section class="container" id="{{ .ID }}">
    <div class="container-header caps">
      {{ translate "general.feed" }}
    </div>
    <div class="container-content feed">
      <a class="link-rss" href="/rss" title="rss feed" download target="_blank">
        {{ translate "general.feed_rss" }}
      </a>
      <a class="link-ical" href="/ical" title="ical feed" download target="_blank">
        {{ translate "general.add_calendar" }}
      </a>
    </div>
  </section>
{{ end }}
